"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "validatePart", {
    enumerable: true,
    get: function() {
        return _validatePart.validatePart;
    }
});
exports.validate = validate;
exports.normalize = normalize;
exports.buildUrl = buildUrl;
exports.default = void 0;
var _resolvers = require("./resolvers");
var _validatePart = require("./validatePart");
function validate(possibleDOI) {
    if (!possibleDOI) return false;
    return !!normalize(possibleDOI);
}
function normalize(possibleDOI) {
    let doi = undefined;
    if (!possibleDOI) return undefined;
    if ((0, _validatePart).validatePart(possibleDOI)) return possibleDOI;
    if (possibleDOI.startsWith('doi:')) {
        doi = possibleDOI.slice(4);
        if ((0, _validatePart).validatePart(doi)) return doi;
    }
    try {
        const url = new URL(possibleDOI.startsWith('http') ? possibleDOI : `http://${possibleDOI}`);
        const resolver = _resolvers.DEFAULT_RESOLVERS.find((r)=>r.test(url)
        );
        if (!resolver) return undefined;
        doi = resolver.parse(url);
    } catch (error) {
    // pass
    }
    if ((0, _validatePart).validatePart(doi)) return doi;
    return undefined;
}
function buildUrl(possibleDOI) {
    const doi = normalize(possibleDOI);
    if (!doi) return undefined;
    return `https://doi.org/${doi}`;
}
var _default = {
    validatePart: _validatePart.validatePart,
    validate,
    normalize,
    buildUrl
};
exports.default = _default;

//# sourceMappingURL=index.js.map